@@ -23,6 +23,9 @@ def bright(img,path,arg):
         value = float(arg[6:])
     except Exception as err:
         print("arg error in set bright, use default value 127")
+    if value > 255 | value < 0:
+        print("bright value {} error,it must lower than 255 and higher than 0")
+        return
     lv = getImageBright(img)
     evalue = value/lv
     img = ImageEnhance.Brightness(img).enhance(evalue)
@@ -54,6 +57,7 @@ def blur(img,path,arg):
     except Exception as err:
         print("arg error in set minimum blur value, use default value 5.0")
     imgblur = getImageBlur(path)
+    
     if imgblur < value:
         img = img.filter(ImageFilter.SHARPEN)
         saveImage(img,path)
@@ -107,7 +111,7 @@ def showHelp():
     print("\tbright[1.0] \t:\t adjust all pixel bright with average level default:127")
     
     
-    print("\tblur[0] \t:\t sharpen image by blur < request blur,default minimum value:5.0")
+    print("\tblur[5.0] \t:\t sharpen image by blur < request blur,default minimum value:5.0")
     
     print('-'*20)
 
